@@ -1,3 +1,5 @@
+import inspect
+import sys
 from contextlib import contextmanager
 from datetime import datetime
 from pathlib import Path
@@ -109,8 +111,41 @@ def exclusive_file_access(filehandle: Union[str, Path], mode: str = "r"):
     lock_path = filehandle.with_suffix(".lock")
     lock = FileLock(lock_path)
     with lock:
+        if not filehandle.exists():
+            filehandle.touch()
         with open(filehandle, mode) as f:
             yield f
 
     # remove the lock file
     lock_path.unlink(missing_ok=True)
+
+
+def get_passed_kwargs() -> Dict[str, str]:
+    passed = sys.argv[1:]
+    kwargs = {}
+    for arg in passed:
+        try:
+            k, v = arg.split("=")
+            kwargs[k] = v
+        except ValueError:
+            raise ValueError(
+                f"Invalid keyword argument passed. Expected the format key=value, got {arg}"
+            )
+    return kwargs
+
+
+def interpret(value: str, parameter: inspect.Parameter) -> Any:
+    is_str = isinstance(parameter.default, str) or parameter.annotation == str
+    return value if is_str else eval(value)
+
+
+def get_passed_kwargs_for(func):
+    kwargs: Dict[str, str] = get_passed_kwargs()
+
+    relevant_kwargs = {}
+    signature = inspect.signature(func)
+    for k, v in kwargs.items():
+        if k in signature.parameters:
+            relevant_kwargs[k] = interpret(v, signature.parameters[k])
+
+    return relevant_kwargs
